@@ -184,10 +184,10 @@ load (GsFolders *folders)
 	ids = g_settings_get_strv (folders->settings, "folder-children");
 	g_object_get (folders->settings, "path", &path, NULL);
 	for (i = 0; ids[i]; i++) {
-		g_autofree gchar **apps = NULL;
-		g_autofree gchar **categories = NULL;
+		g_auto(GStrv) apps = NULL;
+		g_auto(GStrv) categories = NULL;
 		g_autofree gchar *child_path = NULL;
-		g_autofree gchar **excluded_apps = NULL;
+		g_auto(GStrv) excluded_apps = NULL;
 		g_autofree gchar *name = NULL;
 		g_autoptr(GSettings) settings = NULL;
 
@@ -450,12 +450,17 @@ static GsFolder *
 get_app_folder (GsFolders *folders, const gchar *app, GPtrArray *categories)
 {
 	GsFolder *folder;
+	const gchar *category;
 	guint i;
 
 	folder = g_hash_table_lookup (folders->apps, app);
 	if (!folder && categories) {
 		for (i = 0; i < categories->len; i++) {
-			folder = g_hash_table_lookup (folders->categories, g_ptr_array_index (categories, i));
+			category = g_ptr_array_index (categories, i);
+			if (category == NULL)
+				continue;
+
+			folder = g_hash_table_lookup (folders->categories, category);
 			if (folder) {
 				break;
 			}
