@@ -110,6 +110,11 @@ typedef guint64 GsPluginFlags;
  * @GS_PLUGIN_ERROR_PIN_REQUIRED:		PIN required for authentication
  * @GS_PLUGIN_ERROR_ACCOUNT_SUSPENDED:		User account has been suspended
  * @GS_PLUGIN_ERROR_ACCOUNT_DEACTIVATED:	User account has been deactivated
+ * @GS_PLUGIN_ERROR_PLUGIN_DEPSOLVE_FAILED:	The plugins installed are incompatible
+ * @GS_PLUGIN_ERROR_DOWNLOAD_FAILED:		The download action failed
+ * @GS_PLUGIN_ERROR_WRITE_FAILED:		The save-to-disk failed
+ * @GS_PLUGIN_ERROR_INVALID_FORMAT:		The data format is invalid
+ * @GS_PLUGIN_ERROR_DELETE_FAILED:		The delete action failed
  *
  * The failure error types.
  **/
@@ -125,6 +130,11 @@ typedef enum {
 	GS_PLUGIN_ERROR_PIN_REQUIRED,
 	GS_PLUGIN_ERROR_ACCOUNT_SUSPENDED,
 	GS_PLUGIN_ERROR_ACCOUNT_DEACTIVATED,
+	GS_PLUGIN_ERROR_PLUGIN_DEPSOLVE_FAILED,
+	GS_PLUGIN_ERROR_DOWNLOAD_FAILED,
+	GS_PLUGIN_ERROR_WRITE_FAILED,
+	GS_PLUGIN_ERROR_INVALID_FORMAT,
+	GS_PLUGIN_ERROR_DELETE_FAILED,
 	/*< private >*/
 	GS_PLUGIN_ERROR_LAST
 } GsPluginError;
