@@ -25,9 +25,11 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
+#ifdef HAVE_GNOME_DESKTOP
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #include <libgnome-desktop/gnome-bg.h>
 #include <libgnome-desktop/gnome-desktop-thumbnail.h>
+#endif
 
 #include "gs-screenshot-image.h"
 #include "gs-common.h"
@@ -50,7 +52,7 @@ struct _GsScreenshotImage
 	gboolean	 use_desktop_background;
 	guint		 width;
 	guint		 height;
-	gint		 scale;
+	guint		 scale;
 };
 
 G_DEFINE_TYPE (GsScreenshotImage, gs_screenshot_image, GTK_TYPE_BIN)
@@ -79,6 +81,7 @@ gs_screenshot_image_set_error (GsScreenshotImage *ssimg, const gchar *message)
 static GdkPixbuf *
 gs_screenshot_image_get_desktop_pixbuf (GsScreenshotImage *ssimg)
 {
+#ifdef HAVE_GNOME_DESKTOP
 	g_autoptr(GnomeBG) bg = NULL;
 	g_autoptr(GnomeDesktopThumbnailFactory) factory = NULL;
 	g_autoptr(GSettings) settings = NULL;
@@ -89,7 +92,11 @@ gs_screenshot_image_get_desktop_pixbuf (GsScreenshotImage *ssimg)
 	gnome_bg_load_from_preferences (bg, settings);
 	return gnome_bg_create_thumbnail (bg, factory,
 					  gdk_screen_get_default (),
-					  ssimg->width, ssimg->height);
+					  (gint) ssimg->width,
+					  (gint) ssimg->height);
+#else
+	return NULL;
+#endif
 }
 
 static gboolean
@@ -122,8 +129,8 @@ as_screenshot_show_image (GsScreenshotImage *ssimg)
 	} else {
 		/* this is always going to have alpha */
 		pixbuf = gdk_pixbuf_new_from_file_at_scale (ssimg->filename,
-							    ssimg->width * ssimg->scale,
-							    ssimg->height * ssimg->scale,
+							    (gint) (ssimg->width * ssimg->scale),
+							    (gint) (ssimg->height * ssimg->scale),
 							    FALSE, NULL);
 		if (pixbuf != NULL) {
 			if (gs_screenshot_image_use_desktop_background (ssimg, pixbuf)) {
@@ -133,7 +140,8 @@ as_screenshot_show_image (GsScreenshotImage *ssimg)
 				} else {
 					gdk_pixbuf_composite (pixbuf, pixbuf_bg,
 							      0, 0,
-							      ssimg->width, ssimg->height,
+							      (gint) ssimg->width,
+							      (gint) ssimg->height,
 							      0, 0, 1.0f, 1.0f,
 							      GDK_INTERP_NEAREST, 255);
 				}
@@ -147,14 +155,14 @@ as_screenshot_show_image (GsScreenshotImage *ssimg)
 	if (g_strcmp0 (ssimg->current_image, "image1") == 0) {
 		if (pixbuf_bg != NULL) {
 			gs_image_set_from_pixbuf_with_scale (GTK_IMAGE (ssimg->image2),
-							     pixbuf_bg, ssimg->scale);
+							     pixbuf_bg, (gint) ssimg->scale);
 		}
 		gtk_stack_set_visible_child_name (GTK_STACK (ssimg->stack), "image2");
 		ssimg->current_image = "image2";
 	} else {
 		if (pixbuf_bg != NULL) {
 			gs_image_set_from_pixbuf_with_scale (GTK_IMAGE (ssimg->image1),
-							     pixbuf_bg, ssimg->scale);
+							     pixbuf_bg, (gint) ssimg->scale);
 		}
 		gtk_stack_set_visible_child_name (GTK_STACK (ssimg->stack), "image1");
 		ssimg->current_image = "image1";
@@ -183,10 +191,10 @@ gs_screenshot_image_show_blurred (GsScreenshotImage *ssimg,
 
 	if (g_strcmp0 (ssimg->current_image, "image1") == 0) {
 		gs_image_set_from_pixbuf_with_scale (GTK_IMAGE (ssimg->image1),
-						     pb, ssimg->scale);
+						     pb, (gint) ssimg->scale);
 	} else {
 		gs_image_set_from_pixbuf_with_scale (GTK_IMAGE (ssimg->image2),
-						     pb, ssimg->scale);
+						     pb, (gint) ssimg->scale);
 	}
 }
 
@@ -284,7 +292,7 @@ gs_screenshot_image_set_size (GsScreenshotImage *ssimg,
 
 	ssimg->width = width;
 	ssimg->height = height;
-	gtk_widget_set_size_request (ssimg->stack, width, height);
+	gtk_widget_set_size_request (ssimg->stack, (gint) width, (gint) height);
 }
 
 void
@@ -310,12 +318,12 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 				GCancellable *cancellable)
 {
 	AsImage *im = NULL;
-	SoupURI *base_uri = NULL;
 	const gchar *url;
 	g_autofree gchar *basename = NULL;
 	g_autofree gchar *cache_kind = NULL;
 	g_autofree gchar *cachefn_thumb = NULL;
 	g_autofree gchar *sizedir = NULL;
+	g_autoptr(SoupURI) base_uri = NULL;
 
 	g_return_if_fail (GS_IS_SCREENSHOT_IMAGE (ssimg));
 
@@ -324,7 +332,7 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 	g_return_if_fail (ssimg->height != 0);
 
 	/* load an image according to the scale factor */
-	ssimg->scale = gtk_widget_get_scale_factor (GTK_WIDGET (ssimg));
+	ssimg->scale = (guint) gtk_widget_get_scale_factor (GTK_WIDGET (ssimg));
 	im = as_screenshot_get_image (ssimg->screenshot,
 				      ssimg->width * ssimg->scale,
 				      ssimg->height * ssimg->scale);
@@ -414,7 +422,6 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 		/* TRANSLATORS: this is when we try to download a screenshot
 		 * that was not a valid URL */
 		gs_screenshot_image_set_error (ssimg, _("Screenshot not valid"));
-		soup_uri_free (base_uri);
 		return;
 	}
 
@@ -430,7 +437,6 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 	if (ssimg->message == NULL) {
 		/* TRANSLATORS: this is when networking is not available */
 		gs_screenshot_image_set_error (ssimg, _("Screenshot not available"));
-		soup_uri_free (base_uri);
 		return;
 	}
 
@@ -439,7 +445,6 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 				    g_object_ref (ssimg->message) /* transfer full */,
 				    gs_screenshot_image_complete_cb,
 				    g_object_ref (ssimg));
-	soup_uri_free (base_uri);
 }
 
 static void
