@@ -47,9 +47,6 @@ typedef enum {
 	GS_FLATPAK_SCOPE_USER
 } GsFlatpakScope;
 
-#define	GS_FLATPAK_SYSTEM_PREFIX	"flatpak"
-#define	GS_FLATPAK_USER_PREFIX		"user-flatpak"
-
 GsFlatpak	*gs_flatpak_new			(GsPlugin		*plugin,
 						 GsFlatpakScope		 scope);
 gboolean	gs_flatpak_setup		(GsFlatpak		*self,
@@ -63,10 +60,6 @@ gboolean	gs_flatpak_add_sources		(GsFlatpak		*self,
 						 GsAppList		*list,
 						 GCancellable		*cancellable,
 						 GError			**error);
-gboolean	gs_flatpak_add_source		(GsFlatpak		*self,
-						 GsApp			*app,
-						 GCancellable		*cancellable,
-						 GError			**error);
 gboolean	gs_flatpak_add_updates		(GsFlatpak		*self,
 						 GsAppList		*list,
 						 GCancellable		*cancellable,
